invF: Inverse of cumulative function of a marginal distribution.

Description Usage Arguments Value Author(s) Examples

View source: R/invF.R

Description

The value of the inverse cumulative distribution.

Usage

1
invF(u, type = "Exp", num1 = 1, num2 = NULL)

Arguments

u

A numeric value belong to the interval [0,1], corresponding to the cumulative density.

type

Type of marginal distribution. Possible options are "Exp", "Norm", "Unif" and "Gamma". Defaults to "Exp".

num1

A numeric value for the first parameter of the marginal distribution.

num2

A numeric value for the second parameter of the marginal distribution.

Value

A numeric value corresponding to the distribution of the marginal function.

Author(s)

Gustavo Soutinho, Luis Meira-Machado

Examples

1
2
invF(0.2)
invF(0.2,type = 'Norm', num1 = 0.2,num2 = 0.1)

gsoutinho/survCopula documentation built on Sept. 4, 2020, 3:54 a.m.