Description Usage Arguments Value References Examples
Random Number Generation for Bivariate Copula Functions. Only returns a single pair of random values from a bivariate copula with marginal distributions X and Y.
1 2 3 4 5 6 7 8 9 10 11 12 |
v1 |
A numeric value belong to the interval [0,1], corresponding to the cumulative density of the first marginal distribution. |
v2 |
A numeric value belong to the interval [0,1], corresponding to the cumulative density of the first marginal distribution. |
theta |
A numeric value for the space parameter. |
type |
Type of copula. Possible options are |
typeX |
Type of marginal distribution. Possible options are |
num1_X |
A numeric value for the first parameter of the first marginal distribution. Defaults to |
num2_X |
A numeric value for the second parameter of the first marginal distribution. Only required for two parameter distributions. |
typeY |
Type of marginal distribution. Possible options are |
num1_Y |
A numeric value for the first parameter of the second marginal distribution. |
num2_Y |
A numeric value for the second parameter of the second marginal distribution. Only required for two parameter distributions. |
2-dimensional vector for the random variables. See also dgCopula, rcopula
Nelsen R.B. (2006). An Introduction to Copulas (2nd ed.), Springer-Verlag.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.